<?php

/**
 * @link              http://www.flywire.com/
 * @since             1.0.0
 * @package           flywire-woocommerce-multicurrency
 *
 * @wordpress-plugin
 * Plugin Name:       Flywire for WooCommerce Multicurrency Add-On
 * Description:       Set up additional portals/currencies for the Flywire for WooCommerce Payment Gateway.
 * Version:           1.0.0
 * Requires at least: 5.7
 * Author:            Flywire
 * Author URI:        http://www.flywire.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       flywire-multicurrency
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

require plugin_dir_path( __FILE__ ) . 'includes/class-flywire-woocommerce-multicurrency-settings.php';

add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'fwma_settings_link' );

/**
 * Adds a "Configure" link to the plugins page
 *
 * @param array $links Existing plugin links
 *
 * @return array updated links array
 */
function fwma_settings_link( array $links ) {
	$url = esc_url( add_query_arg(
		'page',
		'flywire-multicurrency-settings',
		get_admin_url() . 'options-general.php'
	) );

	$settings_link = "<a href='$url'>" . __( 'Configure' ) . '</a>';

	array_unshift(
		$links,
		$settings_link
	);

	return $links;
}

add_filter( 'flywpg_portal_code', 'fwma_get_flywire_portal', 10, 3 );

/**
 * Checks the current WooCommerce order currency and, if a portal has been
 * defined for that currency, return it in place of the default portal
 *
 * @param string $code - original portal code from flywire-payment-gateway
 * @param WC_Order $order WooCommerce order object.
 * @param boolean $demo_mode - is in demo mode
 *
 * @return string - the currency-specific portal code
 */
function fwma_get_flywire_portal( string $code, WC_Order $order, bool $demo_mode ): string {
	$currency = $order->get_currency();

	// Create a hash array of currencies to associated portals
	$portals    = [];
	$options    = get_option( 'fwma_options' );
	$codes      = $demo_mode ? array_map('trim', explode( ',', $options['demo_portals'] ) ) : array_map('trim', explode( ',', $options['prod_portals'] ) );
	$currencies = array_map('trim', explode( ',', $options['currencies'] ) );

	for ( $i = 0; $i < sizeof( $currencies ); $i ++ ) {
		$portals[ $currencies[ $i ] ] = $codes[ $i ];
	}

	if ( ! sizeof( $portals ) ) {
		return $code;
	} else {
		return $portals[ $currency ] ?: $code;
	}
}